#
# spec file for package perl-Plack
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Plack
Name:           perl-Plack
Version:        1.0051
Release:        1.3
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Perl Superglue for Web frameworks and Web Servers (PSGI toolkit)
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/M/MI/MIYAGAWA/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Apache::LogFormat::Compiler) >= 0.33
BuildRequires:  perl(Cookie::Baker) >= 0.07
BuildRequires:  perl(Devel::StackTrace) >= 1.23
BuildRequires:  perl(Devel::StackTrace::AsHTML) >= 0.11
BuildRequires:  perl(File::ShareDir) >= 1.00
BuildRequires:  perl(File::ShareDir::Install) >= 0.06
BuildRequires:  perl(Filesys::Notify::Simple)
BuildRequires:  perl(HTTP::Entity::Parser) >= 0.25
BuildRequires:  perl(HTTP::Headers::Fast) >= 0.18
BuildRequires:  perl(HTTP::Message) >= 5.814
BuildRequires:  perl(HTTP::Tiny) >= 0.034
BuildRequires:  perl(Hash::MultiValue) >= 0.05
BuildRequires:  perl(Pod::Usage) >= 1.36
BuildRequires:  perl(Stream::Buffered) >= 0.02
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(Test::Requires)
BuildRequires:  perl(Test::TCP) >= 2.15
BuildRequires:  perl(Try::Tiny)
BuildRequires:  perl(URI) >= 1.59
BuildRequires:  perl(WWW::Form::UrlEncoded) >= 0.23
BuildRequires:  perl(parent)
Requires:       perl(Apache::LogFormat::Compiler) >= 0.33
Requires:       perl(Cookie::Baker) >= 0.07
Requires:       perl(Devel::StackTrace) >= 1.23
Requires:       perl(Devel::StackTrace::AsHTML) >= 0.11
Requires:       perl(File::ShareDir) >= 1.00
Requires:       perl(Filesys::Notify::Simple)
Requires:       perl(HTTP::Entity::Parser) >= 0.25
Requires:       perl(HTTP::Headers::Fast) >= 0.18
Requires:       perl(HTTP::Message) >= 5.814
Requires:       perl(HTTP::Tiny) >= 0.034
Requires:       perl(Hash::MultiValue) >= 0.05
Requires:       perl(Pod::Usage) >= 1.36
Requires:       perl(Stream::Buffered) >= 0.02
Requires:       perl(Test::TCP) >= 2.15
Requires:       perl(Try::Tiny)
Requires:       perl(URI) >= 1.59
Requires:       perl(WWW::Form::UrlEncoded) >= 0.23
Requires:       perl(parent)
%{perl_requires}

%description
Plack is a set of tools for using the PSGI stack. It contains middleware
components, a reference server and utilities for Web application
frameworks. Plack is like Ruby's Rack or Python's Paste for WSGI.

See PSGI for the PSGI specification and PSGI::FAQ to know what PSGI and
Plack are and why we need them.

%prep
%autosetup  -n %{cpan_name}-%{version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%changelog
* Sat Jan  6 2024 Tina Müller <timueller+perl@suse.de>
- updated to 1.0051
  see /usr/share/doc/packages/perl-Plack/Changes
  1.0051  2024-01-05 15:09:37 PST
    [BUG FIXES]
  - Fix a bug where $req->headers can pick up non-PSGI header values from environment #703
    [IMPROVEMENTS]
  - Performance improvements on StackTrace middleware by avoiding overloaded methods #697
  - Added tests for Plack::Runner::mangle_host_port_socket #700
* Tue Sep  6 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.0050
  see /usr/share/doc/packages/perl-Plack/Changes
  1.0050  2022-09-05 08:46:44 PDT
    [BUG FIXES]
  - Revert #660 where POST requests failed when Middleware::Static was used with a code in `path` (#683)
  1.0049  2022-09-01 10:43:42 PDT
    [IMPROVEMENTS]
  - Fix typos in docs #659
  - Test improvements, including moving from Travis CI to GitHub
  - Restrict non-GET/HEAD requests to App::File #662
  - Improved nginx FastCGI example #675
  - Added documentation about port 5000 for MacOS Montery
  - Added verify_SSL in Plack::LWPish #677
  - Added 'force' option to IIS6ScriptNameFix #679
* Mon Nov 30 2020 Tina Müller <timueller+perl@suse.de>
- updated to 1.0048
  see /usr/share/doc/packages/perl-Plack/Changes
  1.0048  2020-11-29 16:20:00 PST
    [IMPROVEMENTS]
  - Updated documentation for cotent_length and content_type #625
  - Allow hyphens in file extensions for custom MIME types #614
  - Updated some python test script to work with Python 3 #639
    [BUG FIXES]
  - Fix HTTP::Message::PSGI to work with delayed writer without content #653
  - Plackup reloader allows restarting the server when the path contains .git or .svn, just not at the beginning of the path #632
  - Added MIME types for .webp, .ttf and .xlsx files (rrwo)
  - Fix Plack::Request content to not error when Content-Type is empty #655
* Wed Apr  3 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.0047
  see /usr/share/doc/packages/perl-Plack/Changes
  1.0047  2018-02-10 01:23:37 PST
    [BUG FIXES]
  - Disable FCGI/lighttpd test that was supposed to be releng only #611
  1.0046  2018-02-09 23:51:10 PST
    [NEW FEATURES]
  - Support psgix.cleanup and psgix.harakiri in FCGI handler (afresh1) #610
    [IMPROVEMENTS]
  - Do not set TCP_NODELAY when it's unavailable in embedded systems (dex4er) #579
  1.0045  2017-12-31 12:40:52 PST
    [BUG FIXES]
  - Protect WrapCGI against SIGCHLD handlers #596
    [IMPROVEMENTS]
  - Set Content-Length to 0 in XSendfile middleware #602
  - Document options for XSendfile middleware
  - Remove #foo file for testing that was causing issues on Win32 systems #599
  - Add 103 Early Hints to Plack::Handler::CGI
  1.0044  2017-04-26 22:30:27 PDT
    [IMPROVEMENTS]
  - Allow passing an already-open listen socket to HTTP::Server::PSGI
    and add an option to do so in Plack::Test::Server.
  1.0043  2017-02-21 19:00:31 PST
    [IMPROVEMENTS]
  - Fixed typo in docs #578 #584
  - Remove test that expects cookie to be delimited by comma #573
  - Stop upper-casing all header keys in Plack::Request->headers #585
  1.0042  2016-09-28 22:37:33 PDT
    [BUG FIXES]
  - Revert: Allow passing an already-open listen socket to HTTP::Server::PSGI #550
  1.0041  2016-09-25 14:24:07 PDT
    [BUG FIXES]
  - Fix ConditionalGET middleware in case both Last-Modified and ETag exist. #569
  - Handle Cookie values with quotes correctly (alh, kazeburo) #564, #567
    [IMPROVEMENTS]
  - Several documentation fixes and error message improvements #556, #557, #558, #559
  1.0040  2016-04-01 09:57:06 PDT
    [INCOMPATIBLE CHANGES]
  - Fixes a mistake in the value of %%D and %%T in Accesslog::Timed middleware.
    This is due to a bug in Apache::LogFormat::Compiler that sets a wrong value
    for these fields. This bug has been fixed and now it emits what the documentation
    has always said, in the same way as how Apache's log format works.
    However, this is a BREAKING CHANGE if you are using '%%D' or '%%T' in your log
    formats, and you'll likely need to swap them if you need the same values as
    previously. Read https://github.com/plack/Plack/issues/549 for more details.
    (astj) #549, #551
    [IMPROVEMENTS]
  - Remove the use of HTTP::Body in favor of HTTP::Entity::Parser (kazeburo) #538
  - Increase the buffer size to 1MB for requests already buffered by the PSGI server
  - Allow passing an already-open listen socket to HTTP::Server::PSGI (ilmari) #550
    [BUG FIXES]
  - Lint middleware now allows blessed code refs as a PSGI app (smcmurray) #542
  - Fix log4perl tests to pass when running in parallel (rsimoes) #545
* Thu Jun  2 2016 coolo@suse.com
- update to 1.0039
    [BUG FIXES]
  - Revert the change to use the faster header builder because it breaks the legit
    Plack::Response constructor that sets HTTP::Header object directly (#541)
  1.0038  2015-11-25 12:36:29 PST
    [IMPROVEMENTS]
  - Added MIME type for apk files #514 (allanwhiteford)
  - Allow passing custom formatters to Plack::Middleware::AccessLog #515 (frew)
  - Allow '0' be a valid category for log4perl middleware #523
  - Doc fix for Plack::Runner #528 (polettix)
  - Doc improvements for -R/-M command line #529 (mickeyn)
  - Bind test server explicitly on 127.0.0.1, not 0.0.0.0
  - Support single-process manager in FCGI #535 (ianburrell)
  - Optimize Plack::Response header builder #540 (kazeburo)
  1.0037  2015-06-19 10:01:31 PDT
    [Improvements]
  - Lint: Support HTTP/2 in SERVER_PROTOCOL (kazuho) #511
  - Bump HTTP::Headers::Fast dependency #512
  1.0036  2015-06-03 12:01:53 PDT
    [BUG FIXES]
  - Fix CGIBin test to not use CGI.pm #509
  1.0035  2015-04-16 10:08:21 CEST
    [BUG FIXES]
  - Fixed parsing of empty query string pairs (aristotle) #500
    [IMPROVEMENTS]
  - Documentation updates for FCGI (otrosien) #494
  - Use HTTP::Headers::Fast in Plack::Request
  - Big performance optimizations on Plack::Util::header_* (aristotle) #498
  - Added .webm to Plack::MIME (marlencrabapple) #503
  - Use Cookie::Baker to bake cookies in Plack::Response (oalders)
  - reduced the size of distribution by making binary files smaller
* Mon Apr 13 2015 coolo@suse.com
- updated to 1.0034
  see /usr/share/doc/packages/perl-Plack/Changes
  1.0034  2015-02-02 21:42:42 CET
    [SECURITY]
  - Fixed a possible directory traversal with Plack::App::File on Win32 (sri)
    [IMPROVEMENTS]
  - Documentation improvements (timbunce, oalders, autarch, frioux)
  - Avoid warnings in Plack::App::WrapCGI (frioux)
  1.0033  2014-10-23 12:33:18 PDT
    [BUG FIXES]
  - Lint: Fix error messages (fgabolde) #473
  - ErrorDocument: Reverse the $done filtering (nwellnhof) #474
    [IMPROVEMENTS]
  - StackTrace: Improve the accuracy of thrown exceptions in case where an excpetion
    is thrown in destructors (nwellnhof) #476
  1.0032  2014-10-04 11:13:24 PDT
    [IMPROVEMENTS]
  - Support Server::Starter in FCGI handler (yuryu) #435
  - Various documentation fixes
* Tue Sep 16 2014 coolo@suse.com
- updated to 1.0031
    [SECURITY]
  - Plack::App::File would previously strip trailing slashes off
    provided paths. This in combination with the common pattern
    of serving files with Plack::Middleware::Static could allow
    an attacker to bypass a whitelist of generated files (avar) #446
    [IMPROVEMENTS]
  - Let HTTP::Message::PSGI warn in case of invalid PSGI response (wchristian) #437
  - Update documentation on how response_cb works with writer (doy)
  - Make AccessLog work on non-POSIX environment (dex4er) #442
  - Plack::App::WrapCGI no longer warns under 5.19.9 (frew)
  - Avoid Rosetta Flash attack in JSONP middleware (nichtich) #464
  - Fix Plack::Util::inline_object to make it work with can() as a class method
    [NEW FEATURES]
  - Add $req->query_string shortcut to access QUERY_STRING in PSGI environment
* Mon Nov 25 2013 coolo@suse.com
- updated to 1.0030
  [IMPROVEMENTS]
  - Middleware::LogDispatch stringifies objects (oalders) #427
  - Encode wide character strings as UTF-8 in HTTP::Server::PSGI #429
  - Optimize Plack::Response->finalize performance (kazeburo) #433
  - Optimize mount() performance in Plack::App::URLMap
  [BUG FIXES]
  - ErrorDocument: remove Content-Encoding and Transfer-Encoding (kazeburo) #430
  - Fix harakiri test hang on win32 (wchristian) #431
  - Handler::FCGI: Restore --keep-stderr option (mauzo) #432
* Fri Oct  4 2013 coolo@suse.com
- updated to 1.0029
  [NEW FEATURES]
  - Plack::Test now has a simpler object-oriented interface that doesn't
    take multiple callbacks. #420
  [IMPROVEMENTS]
  - bump dependencies for Test::TCP and HTTP::Tiny
  - Set no_proxy for HTTP::Tiny in tests (kazeburo)
  [INCOMPATIBLE CHANGES]
  - Split HTTP::Server::Simple handler from Plack distribution and merge to
    HTTP-Server-Simple-PSGI distribution
* Tue Jul  9 2013 coolo@suse.com
- updated to 1.0028
* Tue Jul  9 2013 coolo@suse.com
- update to 1.0028
    [IMPROVEMENTS]
  - Skip cgi related tests for Win32 (chorny) #413
  - Skip tests that could potentially write empty bytes, which could cause
    issues on some servers on local sockets with HTTP::Tiny
  - Skip tests that require HTTP::Cookies, if not available #414
  - Not a dev release, including XS free version of Plack::Test*
  - Fix cgibin tests that often fail on Win32 #375
    [INCOMPATIBLE CHANGES]
  - use HTTP::Tiny in Plack::Test::Suite and Plack::Test::Server rather than skipping it.
  - No XS! Eliminates dependency to LWP::UserAgent by making it completely optional for
    testing. If you run Plack::Test with Server implemenetation or run Plack::Test::Suite
    (for PSGI handlers) without LWP installed, the tests will automatically be skipped.
    This removes the eventual sub-dependency to HTML::Parser, which is the only XS dependency
    in Plack. #408
    [IMPROVEMENTS]
  - Fixed the warning in OO usage of Plack::Builder (doy) #407
  - Shotgun loader now dies if used in Win32 since it leaks memory #320, #400
  - Suppress warnings for Test::TCP (kazeburo) #406
  - $res->to_app shortcut (ether) #409
  - Fix warnings for Plack::App::WrapCGI (frioux)
  - Ignore emacs lock file from restarter (maio)
  - Add documentation for environment variable in Auth::Basic
  - Some Metadata cleanup and Travis CI
  - Use Apache::LogFormat::Compiler in AccessLog (kazeburo)
    [BUG FIXES]
  - Fixed a major bug in 1.0020-1.0021 where posix_default prevents arbitrary arguments
    for plackup-compat (e.g. starman) to handle them (Thanks to justnoxx) Starman#66
    [IMPROVEMENTS]
  - Fixed test warnings (Keedi Kim)
  - Repackage with Milla v0.9.6 #392
* Fri Jul  5 2013 dvaleev@suse.com
- Remove the test that has : in HTTP headers which now chokes on
  new HTTP::Headers
* Wed May 30 2012 coolo@suse.com
- reduce build requires - test suites are fine, build cycles are bad
* Wed May 30 2012 coolo@suse.com
- updated to 0.9988
  - Fixes HTTP_HOST in HTTP::Message::PSGI #287 (doy)
  [IMPROVEMENTS]
  - Support streaming in AccessLog::Timed (Peter Makholm)
  - Support streaming in ErrorDocument
  - Removed UTF8 hack in HTTP::Message::PSGI. Depends on URI.pm 1.59 (wreis)
  - Set Host headers correctly in HTTP::Message::PSGI #177
  - Added documentation on supported %%-flags in AccessLog (ether)
  - Skip unnecessary tests on non-developer environment
* Fri Mar 16 2012 lars@linux-schulserver.de
- update to 0.9986:
  + Use I/O handles to FCGI::Request instead of global STDIN,
    STDOUT etc.
  + Improved FastCGI docs
  + Cascade app now returns the last response code
* Tue Nov  1 2011 lars@linux-schulserver.de
- update to 0.9985:
  + Short circuit Plack::Handler fallback to avoid %%INC bugs
    in perl 5.8
  + Fixed Makefile.PL to avoid Test::SharedFork interferring
    with Module::Install
* Mon Oct 31 2011 pascal.bleser@opensuse.org
- update to 0.9984:
  + WrapCGI: Close wrapped CGI's STDIN handle
  + WrapCGI: improved docs
  + Request: Do not destroy HTTP::Body upload headers
* Wed May 11 2011 dbahi@novell.com
- Fixed a failing output_encoding.t because of FCGI dependencies
- Improved Plack::Test::Suite documentation
- Fixed ConditionalGET to not die with streaming interface
- Add a reason string to CGI/FastCGI Status header to comply with RFC 3875
- Fixed a CGI/FastCGI handler to ensure newlines are not mangled on Win32 platforms
- localize @ARGV to empty when evaluating a PSGI application
  (https://github.com/sukria/Dancer/issues/473)
- Fixed the use of Getopt::Long to make the pass_through flag local
- Middleware::JSONP now supports more response types such as IO::Handle
* Sat Apr 30 2011 coolo@opensuse.org
- updated to 0.9976, see Changes
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Fri Nov  5 2010 pascal.bleser@opensuse.org
- update to 0.9951:
  * added Feersum to the benchmark script
  * StackTrace: store the stacktrace in $env->{'plack.stacktrace.text'} and $env->{'plack.stacktrace.html'}
  * added ->mount method to the Plack::Builder OO interface
  * HTTPExceptions: don't set an invalid Content-Length when the exception is not an object
  * ErrorDocument: fixed wrong Content-Length header be set
- changes from 0.9950:
  * fixed typos in middleware docs
  * App::Directory: fixed URL generation escape bug
  * Middleware::JSONP: support callback parameter name
* Wed Sep 22 2010 dbahi@novell.com
- no_plan work and other test requires work
* Mon Sep 20 2010 dbahi@novell.com
- initial package 0.9949
  * created by cpanspec 1.78
